@@ -5,11 +5,10 @@ Unlike _helpers.py, here the methods should be used only in mixins.
 import functools
 import math
 import re
-from typing import Tuple, Union
+from typing import Tuple, Union, Optional, Any, Type
 
 from . import _msgs as msgs
-from ._helpers import null_terminate, SimpleError, SimpleString
-from ._zset import ZSet
+from ._helpers import null_terminate, SimpleError, Database
 
 MAX_STRING_SIZE = 512 * 1024 * 1024
 SUPPORTED_COMMANDS = dict()  # Dictionary of supported commands name => Signature
@@ -18,9 +17,10 @@ COMMANDS_WITH_SUB = set()  # Commands with sub-commands
 
 class Key:
     """Marker to indicate that argument in signature is a key"""
+
     UNSPECIFIED = object()
 
-    def __init__(self, type_=None, missing_return=UNSPECIFIED):
+    def __init__(self, type_: Optional[Type[Any]] = None, missing_return: Any = UNSPECIFIED) -> None:
         self.type_ = type_
         self.missing_return = missing_return
 
@@ -28,9 +28,9 @@ class Key:
 class Item:
     """An item stored in the database"""
 
-    __slots__ = ['value', 'expireat']
+    __slots__ = ["value", "expireat"]
 
-    def __init__(self, value):
+    def __init__(self, value: Any) -> None:
         self.value = value
         self.expireat = None
 
@@ -41,7 +41,7 @@ class CommandItem:
     It wraps an Item but has extra fields to manage updates and notifications.
     """
 
-    def __init__(self, key, db, item=None, default=None):
+    def __init__(self, key: bytes, db: Database, item: Optional["CommandItem"] = None, default: Any = None) -> None:
         if item is None:
             self._value = default
             self._expireat = None
@@ -54,58 +54,59 @@ class CommandItem:
         self._expireat_modified = False
 
     @property
-    def value(self):
+    def value(self) -> Any:
         return self._value
 
     @value.setter
-    def value(self, new_value):
+    def value(self, new_value: Any) -> None:
         self._value = new_value
         self._modified = True
         self.expireat = None
 
     @property
-    def expireat(self):
+    def expireat(self) -> Optional[int]:
         return self._expireat
 
     @expireat.setter
-    def expireat(self, value):
+    def expireat(self, value: int) -> None:
         self._expireat = value
         self._expireat_modified = True
         self._modified = True  # Since redis 6.0.7
 
-    def get(self, default):
+    def get(self, default: Any) -> Any:
         return self._value if self else default
 
-    def update(self, new_value):
+    def update(self, new_value: Any) -> None:
         self._value = new_value
         self._modified = True
 
-    def updated(self):
+    def updated(self) -> None:
         self._modified = True
 
-    def writeback(self, remove_empty_val=True):
+    def writeback(self, remove_empty_val: bool = True) -> None:
         if self._modified:
             self.db.notify_watch(self.key)
-            if (not isinstance(self.value, bytes) and (
-                    self.value is None or (not self.value and remove_empty_val))):
+            if (not isinstance(self.value, bytes)
+                    and (self.value is None or (not self.value and remove_empty_val))):
                 self.db.pop(self.key, None)
                 return
-            else:
-                item = self.db.setdefault(self.key, Item(None))
-                item.value = self.value
-                item.expireat = self.expireat
-        elif self._expireat_modified and self.key in self.db:
+            item = self.db.setdefault(self.key, Item(None))
+            item.value = self.value
+            item.expireat = self.expireat
+            return
+
+        if self._expireat_modified and self.key in self.db:
             self.db[self.key].expireat = self.expireat
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self._value) or isinstance(self._value, bytes)
 
     __nonzero__ = __bool__  # For Python 2
 
 
-class Hash(dict):
+class Hash(dict):  # type:ignore
     DECODE_ERROR = msgs.INVALID_HASH_MSG
-    redis_type = b'hash'
+    redis_type = b"hash"
 
 
 class Int:
@@ -113,25 +114,25 @@ class Int:
 
     DECODE_ERROR = msgs.INVALID_INT_MSG
     ENCODE_ERROR = msgs.OVERFLOW_MSG
-    MIN_VALUE = -2 ** 63
+    MIN_VALUE = -(2 ** 63)
     MAX_VALUE = 2 ** 63 - 1
 
     @classmethod
-    def valid(cls, value):
+    def valid(cls, value: int) -> bool:
         return cls.MIN_VALUE <= value <= cls.MAX_VALUE
 
     @classmethod
-    def decode(cls, value, decode_error=None):
+    def decode(cls, value: bytes, decode_error: Optional[str] = None) -> int:
         try:
             out = int(value)
             if not cls.valid(out) or str(out).encode() != value:
                 raise ValueError
+            return out
         except ValueError:
             raise SimpleError(decode_error or cls.DECODE_ERROR)
-        return out
 
     @classmethod
-    def encode(cls, value):
+    def encode(cls, value: int) -> bytes:
         if cls.valid(value):
             return str(value).encode()
         else:
@@ -178,19 +179,22 @@ class Float:
     DECODE_ERROR = msgs.INVALID_FLOAT_MSG
 
     @classmethod
-    def decode(cls, value,
-               allow_leading_whitespace=False,
-               allow_erange=False,
-               allow_empty=False,
-               crop_null=False,
-               decode_error=None):
+    def decode(
+            cls,
+            value: bytes,
+            allow_leading_whitespace: bool = False,
+            allow_erange: bool = False,
+            allow_empty: bool = False,
+            crop_null: bool = False,
+            decode_error: Optional[str] = None,
+    ) -> float:
         # redis has some quirks in float parsing, with several variants.
         # See https://github.com/antirez/redis/issues/5706
         try:
             if crop_null:
                 value = null_terminate(value)
-            if allow_empty and value == b'':
-                value = b'0.0'
+            if allow_empty and value == b"":
+                value = b"0.0"
             if not allow_leading_whitespace and value[:1].isspace():
                 raise ValueError
             if value[-1:].isspace():
@@ -202,93 +206,106 @@ class Float:
                 # Values that over- or underflow- are explicitly rejected by
                 # redis. This is a crude hack to determine whether the input
                 # may have been such a value.
-                if out in (math.inf, -math.inf, 0.0) and re.match(b'^[^a-zA-Z]*[1-9]', value):
+                if out in (math.inf, -math.inf, 0.0) and re.match(b"^[^a-zA-Z]*[1-9]", value):
                     raise ValueError
             return out
         except ValueError:
             raise SimpleError(decode_error or cls.DECODE_ERROR)
 
     @classmethod
-    def encode(cls, value, humanfriendly):
+    def encode(cls, value: float, humanfriendly: bool) -> bytes:
         if math.isinf(value):
             return str(value).encode()
         elif humanfriendly:
             # Algorithm from ld2string in redis
-            out = '{:.17f}'.format(value)
-            out = re.sub(r'\.?0+$', '', out)
+            out = "{:.17f}".format(value)
+            out = re.sub(r"\.?0+$", "", out)
             return out.encode()
         else:
-            return '{:.17g}'.format(value).encode()
+            return "{:.17g}".format(value).encode()
 
 
 class SortFloat(Float):
     DECODE_ERROR = msgs.INVALID_SORT_FLOAT_MSG
 
     @classmethod
-    def decode(cls, value, **kwargs):
+    def decode(
+            cls,
+            value: bytes,
+            allow_leading_whitespace: bool = True,
+            allow_erange: bool = False,
+            allow_empty: bool = True,
+            crop_null: bool = True,
+            decode_error: Optional[str] = None,
+    ) -> float:
         return super().decode(
-            value, allow_leading_whitespace=True, allow_empty=True, crop_null=True)
+            value, allow_leading_whitespace=True, allow_empty=True, crop_null=True
+        )
 
 
 @functools.total_ordering
 class BeforeAny:
-    def __gt__(self, other):
+    def __gt__(self, other: Any) -> bool:
         return False
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return isinstance(other, BeforeAny)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return 1
 
 
 @functools.total_ordering
 class AfterAny:
-    def __lt__(self, other):
+    def __lt__(self, other: Any) -> bool:
         return False
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return isinstance(other, AfterAny)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return 1
 
 
 class ScoreTest:
     """Argument converter for sorted set score endpoints."""
 
-    def __init__(self, value: float, exclusive: bool = False, bytes_val: bytes = None):
+    def __init__(self, value: float, exclusive: bool = False, bytes_val: Optional[bytes] = None):
         self.value = value
         self.exclusive = exclusive
         self.bytes_val = bytes_val
 
     @classmethod
-    def decode(cls, value):
+    def decode(cls, value: bytes) -> "ScoreTest":
         try:
             original_value = value
             exclusive = False
-            if value[:1] == b'(':
+            if value[:1] == b"(":
                 exclusive = True
                 value = value[1:]
-            value = Float.decode(
-                value, allow_leading_whitespace=True, allow_erange=True,
-                allow_empty=True, crop_null=True)
-            return cls(value, exclusive, original_value)
+            fvalue = Float.decode(
+                value,
+                allow_leading_whitespace=True,
+                allow_erange=True,
+                allow_empty=True,
+                crop_null=True,
+            )
+            return cls(fvalue, exclusive, original_value)
         except SimpleError:
             raise SimpleError(msgs.INVALID_MIN_MAX_FLOAT_MSG)
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self.exclusive:
-            return '({!r}'.format(self.value)
+            return "({!r}".format(self.value)
         else:
             return repr(self.value)
 
     @property
-    def lower_bound(self):
+    def lower_bound(self) -> Tuple[float, Union[AfterAny, BeforeAny]]:
         return self.value, AfterAny() if self.exclusive else BeforeAny()
 
     @property
-    def upper_bound(self):
+    def upper_bound(self) -> Tuple[float, Union[AfterAny, BeforeAny]]:
         return self.value, BeforeAny() if self.exclusive else AfterAny()
 
 
@@ -300,24 +317,25 @@ class StringTest:
         self.exclusive = exclusive
 
     @classmethod
-    def decode(cls, value: bytes) -> 'StringTest':
-        if value == b'-':
+    def decode(cls, value: bytes) -> "StringTest":
+        if value == b"-":
             return cls(BeforeAny(), True)
-        elif value == b'+':
+        elif value == b"+":
             return cls(AfterAny(), True)
-        elif value[:1] == b'(':
+        elif value[:1] == b"(":
             return cls(value[1:], True)
-        elif value[:1] == b'[':
+        elif value[:1] == b"[":
             return cls(value[1:], False)
         else:
             raise SimpleError(msgs.INVALID_MIN_MAX_STR_MSG)
 
-    def to_scoretest(self, zset: ZSet):
-        if isinstance(self.value, BeforeAny):
-            return ScoreTest(float('-inf'), False)
-        if isinstance(self.value, AfterAny):
-            return ScoreTest(float('inf'), False)
-        return ScoreTest(zset.get(self.value, None), self.exclusive)
+    # def to_scoretest(self, zset: ZSet) -> ScoreTest:
+    #     if isinstance(self.value, BeforeAny):
+    #         return ScoreTest(float("-inf"), False)
+    #     if isinstance(self.value, AfterAny):
+    #         return ScoreTest(float("inf"), False)
+    #     val: float = zset.get(self.value, None)
+    #     return ScoreTest(val, self.exclusive)
 
 
 class Signature:
@@ -336,7 +354,11 @@ class Signature:
                 msg = msgs.WRONG_ARGS_MSG6.format(self.name)
                 raise SimpleError(msg)
             if delta % len(self.repeat) != 0:
-                msg = msgs.WRONG_ARGS_MSG7 if version >= (7,) else msgs.WRONG_ARGS_MSG6.format(self.name)
+                msg = (
+                    msgs.WRONG_ARGS_MSG7
+                    if version >= (7,)
+                    else msgs.WRONG_ARGS_MSG6.format(self.name)
+                )
                 raise SimpleError(msg)
 
     def apply(self, args, db, version):
@@ -355,9 +377,11 @@ class Signature:
         for i, (arg, type_) in enumerate(zip(args, types)):
             if isinstance(type_, Key):
                 if type_.missing_return is not Key.UNSPECIFIED and arg not in db:
-                    return type_.missing_return,
+                    return (type_.missing_return,)
             elif type_ != bytes:
-                args[i] = type_.decode(args[i], )
+                args[i] = type_.decode(
+                    args[i],
+                )
 
         # Second pass: read keys and check their types
         command_items = []
@@ -365,13 +389,17 @@ class Signature:
             if isinstance(type_, Key):
                 item = db.get(arg)
                 default = None
-                if (type_.type_ is not None
+                if (
+                        type_.type_ is not None
                         and item is not None
-                        and type(item.value) is not type_.type_):
+                        and type(item.value) is not type_.type_
+                ):
                     raise SimpleError(msgs.WRONGTYPE_MSG)
-                if (type_.type_ is not None
+                if (
+                        type_.type_ is not None
                         and item is None
-                        and type_.type_ is not bytes):
+                        and type_.type_ is not bytes
+                ):
                     default = type_.type_()
                 args[i] = CommandItem(arg, db, item, default=default)
                 command_items.append(args[i])
@@ -381,12 +409,14 @@ class Signature:
 
 def command(*args, **kwargs):
     def create_signature(func, cmd_name):
-        if ' ' in cmd_name:
-            COMMANDS_WITH_SUB.add(cmd_name.split(' ')[0])
-        SUPPORTED_COMMANDS[cmd_name] = Signature(cmd_name, func.__name__, *args, **kwargs)
+        if " " in cmd_name:
+            COMMANDS_WITH_SUB.add(cmd_name.split(" ")[0])
+        SUPPORTED_COMMANDS[cmd_name] = Signature(
+            cmd_name, func.__name__, *args, **kwargs
+        )
 
     def decorator(func):
-        cmd_names = kwargs.pop('name', func.__name__)
+        cmd_names = kwargs.pop("name", func.__name__)
         if isinstance(cmd_names, list):  # Support for alias commands
             for cmd_name in cmd_names:
                 create_signature(func, cmd_name.lower())
@@ -399,7 +429,7 @@ def command(*args, **kwargs):
     return decorator
 
 
-def delete_keys(*keys):
+def delete_keys(*keys: CommandItem) -> int:
     ans = 0
     done = set()
     for key in keys:
@@ -410,7 +440,7 @@ def delete_keys(*keys):
     return ans
 
 
-def fix_range(start, end, length):
+def fix_range(start: int, end: int, length: int) -> Tuple[int, int]:
     # Redis handles negative slightly differently for zrange
     if start < 0:
         start = max(0, start + length)
@@ -422,7 +452,7 @@ def fix_range(start, end, length):
     return start, end + 1
 
 
-def fix_range_string(start, end, length):
+def fix_range_string(start: int, end: int, length: int) -> Tuple[int, int]:
     # Negative number handling is based on the redis source code
     if 0 > start > end and end < 0:
         return -1, -1
@@ -432,20 +462,3 @@ def fix_range_string(start, end, length):
         end = max(0, end + length)
     end = min(end, length - 1)
     return start, end + 1
-
-
-def key_value_type(key):
-    if key.value is None:
-        return SimpleString(b'none')
-    elif isinstance(key.value, bytes):
-        return SimpleString(b'string')
-    elif isinstance(key.value, list):
-        return SimpleString(b'list')
-    elif isinstance(key.value, set):
-        return SimpleString(b'set')
-    elif isinstance(key.value, ZSet):
-        return SimpleString(b'zset')
-    elif isinstance(key.value, dict):
-        return SimpleString(b'hash')
-    else:
-        assert False  # pragma: nocover
