@@ -1,16 +1,18 @@
 import time
+from typing import Any
 
 from fakeredis import _msgs as msgs
-from fakeredis._commands import (command, DbIndex)
-from fakeredis._helpers import (OK, SimpleError, casematch, BGSAVE_STARTED)
+from fakeredis._commands import command, DbIndex
+from fakeredis._helpers import OK, SimpleError, casematch, BGSAVE_STARTED, Database
 
 
 class ServerCommandsMixin:
-    # TODO: lots
+    _server: Any
+    _db: Database
 
     @command((), (bytes,), flags=msgs.FLAG_NO_SCRIPT)
     def bgsave(self, *args):
-        if len(args) > 1 or (len(args) == 1 and not casematch(args[0], b'schedule')):
+        if len(args) > 1 or (len(args) == 1 and not casematch(args[0], b"schedule")):
             raise SimpleError(msgs.SYNTAX_ERROR_MSG)
         self._server.lastsave = int(time.time())
         return BGSAVE_STARTED
@@ -21,14 +23,14 @@ class ServerCommandsMixin:
 
     @command((), (bytes,))
     def flushdb(self, *args):
-        if len(args) > 0 and (len(args) != 1 or not casematch(args[0], b'async')):
+        if len(args) > 0 and (len(args) != 1 or not casematch(args[0], b"async")):
             raise SimpleError(msgs.SYNTAX_ERROR_MSG)
         self._db.clear()
         return OK
 
     @command((), (bytes,))
     def flushall(self, *args):
-        if len(args) > 0 and (len(args) != 1 or not casematch(args[0], b'async')):
+        if len(args) > 0 and (len(args) != 1 or not casematch(args[0], b"async")):
             raise SimpleError(msgs.SYNTAX_ERROR_MSG)
         for db in self._server.dbs.values():
             db.clear()
